==> haskell-bv-sized-1.0.6-85.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-2raI8yHQ82GFPGxfcVuSqH
key:                  bv-sized-1.0.6-2raI8yHQ82GFPGxfcVuSqH
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  e015c32b1b40338bbba812de8da86668
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-2raI8yHQ82GFPGxfcVuSqH
depends:
    base-4.18.2.1 bitwise-1.0.0.1-9aRHZTm9IHk5MFY6E8IsGB
    bytestring-0.11.5.3 deepseq-1.4.8.1
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.10.0-JrHhOIzx0jD6F8IOBE0P3g
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bv-sized-1.0.6-86-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-3jfyfKVjGc0JZuVXsIuZ3Z
key:                  bv-sized-1.0.6-3jfyfKVjGc0JZuVXsIuZ3Z
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  08705df10c09e05ac7239b3208962386
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-3jfyfKVjGc0JZuVXsIuZ3Z
depends:
    base-4.18.2.1 bitwise-1.0.0.1-ADhNvosKClRH4caCpl05Mp
    bytestring-0.11.5.3 deepseq-1.4.8.1
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.10.0-K9k2WU6P2flDyJ9do22sx8
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
